# Laurent Tupin - pynut

It provides various functions to provide additionnal functionnalities
For more information see the tutorial ...

## Installation

You can install the package from [PyPI](https://pypi.org/project/pynut/):
    python -m pip install pynut
The package is supported on Python 3.7 and above.

## How to use

    $ ...
    


You can also call the Real Python Feed Reader in your own Python code, by importing from the `reader` package:

    >>> from pynut import pyNut
    >>> pyNut.nutDate.today()
  